@@ -93,6 +93,24 @@ class DiffConvert:
     and the update() method would return the commands required to change
     it to the new value.
 
+    The methods called to do the conversions are:
+
+    * add(new, *args) -- appears in the new configuration but was not
+      present in the old configuration; calls update(None, new, new,
+      *args) by default.
+
+    * remove(old, *args) -- appears in the old configuration but is not
+      present in the new configuration; calls truncate(old, old, None,
+      *args) by default).
+
+    * truncate(old, rem, new, *args) -- appears in the remove
+      differences but still exists in the new configuration - i.e. is
+      being partially removed.
+
+    * update(old, upd, new, *args) -- appers in the update differences
+      and existed in the old configuration - i.e. is being changed or
+      added to.
+
     The 'context', 'cmd' and 'ext' parameters, below, are all tuples
     giving parts of the path through the keys of the configuration
     dictionary to match for the specific converter.  These can be
@@ -157,13 +175,13 @@ class DiffConvert:
         # definitions for this converter class are all tuples and not
         # something like simple strings
         if not (isinstance(self.context, tuple)):
-            raise TypeError("class %s: definition not tuple: context"
+            raise TypeError("%s: definition not tuple: context"
                                 % repr(type(self)))
         if not (isinstance(self.cmd, tuple)):
-            raise TypeError("class %s: definition not tuple: cmd"
+            raise TypeError("%s: definition not tuple: cmd"
                                 % repr(type(self)))
         if not (isinstance(self.ext, tuple)):
-            raise TypeError("class %s: definition not tuple: ext"
+            raise TypeError("%s: definition not tuple: ext"
                                 % repr(type(self)))
 
         # calculate and store a few things, for efficiency
@@ -411,7 +429,7 @@ class DiffConvert:
             return None
 
 
-    def get_ext(self, cfg):
+    def get_ext(self, cfg, *args):
         """This method gets the extension part of the path, given a
         configuration dictionary starting at the path (i.e. what is
         passed as 'old/new' and 'rem/upd' in the action methods).
@@ -419,9 +437,23 @@ class DiffConvert:
         An action method [remove() or update()] can use this to get the
         extension portion without needing to explicitly index through
         it.
+
+        If the extension contains any wildcard elements (= None), these
+        will be filled from the supplied 'args'.  The number of args
+        must be the same (or larger) than the number of wildcard fields,
+        else an error will occur.
         """
 
-        return deepget(cfg, *self.ext)
+        # get the extension path, filling in the wildcards (= None) with
+        # the supplied matched arguments
+        ext_match = []
+        for i in self.ext:
+            if i is None:
+                i = args[0]
+                args = args[1:]
+            ext_match.append(i)
+
+        return deepget(cfg, *ext_match)
 
 
     def get_wildcard_args(self, match):
@@ -1226,13 +1258,17 @@ class DiffConfig:
                             diff = cvt.remove(cvt_old, *args)
 
                     except:
-                        print("%s.%s() with:"
-                                  % (repr(type(cvt)),
+                        self._print_debug(debug_msg)
+
+                        print("Exception in %s.%s() with:"
+                                  % (type(cvt).__name__,
                                      "truncate" if remove_is_truncate
                                          else "remove"),
                               "  *args=" + repr(args),
                               sep="\n", file=sys.stderr)
 
+                        print()
+
                         raise
 
 
@@ -1365,12 +1401,16 @@ class DiffConfig:
                             diff = cvt.update(cvt_old, cvt_upd, cvt_new, *args)
 
                     except:
-                        print("%s.%s() with:"
-                                  % (repr(type(cvt)),
+                        self._print_debug(debug_msg)
+
+                        print("Exception in %s.%s() with:"
+                                  % (type(cvt).__name__,
                                      "add" if update_is_add else "update"),
                               "  *args=" + repr(args),
                               sep="\n", file=sys.stderr)
 
+                        print()
+
                         raise
 
 
