@@ -82,9 +82,14 @@ class Cvt_TrackUpdate(DiffConvert):
     cmd = "track", None
     ext = "type",
 
+    # when the type of a tracking object is changed, it must be deleted
+    # and the new type created - this does not need to happen when a new
+    # one is added, though
+
+    def add(self, new, track_num):
+        pass
+
     def update(self, old, upd, new, track_num):
-        # when the type of a tracking object is changed, it must be
-        # deleted and the new type created
         return "no track " + str(track_num)
 
 
@@ -132,40 +137,40 @@ class Cvt_Track_Delay(DiffConvert_TrackSub):
     cmd = "delay",
 
     def remove(self, old, obj):
-        return [*self.enter(obj), " no delay"]
+        return self.enter(obj) + [" no delay"]
 
     def update(self, old, upd, new, obj):
-        return [*self.enter(obj), " delay " + new]
+        return self.enter(obj) + [" delay " + new]
 
 
 class Cvt_Track_IPVRF(DiffConvert_TrackSub):
     cmd = "ip-vrf",
 
     def remove(self, old, obj):
-        return [*self.enter(obj), " no ip vrf"]
+        return self.enter(obj) + [" no ip vrf"]
 
     def update(self, old, upd, new, obj):
-        return [*self.enter(obj), " ip vrf " + new]
+        return self.enter(obj) + [" ip vrf " + new]
 
 
 class Cvt_Track_IPv6VRF(DiffConvert_TrackSub):
     cmd = "ipv6-vrf",
 
     def remove(self, old, obj):
-        return [*self.enter(obj), " no ipv6 vrf"]
+        return self.enter(obj) + [" no ipv6 vrf"]
 
     def update(self, old, upd, new, obj):
-        return [*self.enter(obj), " ipv6 vrf " + new]
+        return self.enter(obj) + [" ipv6 vrf " + new]
 
 
 class Cvt_Track_ListObj(DiffConvert_TrackSub):
     cmd = "object", None
 
     def remove(self, old, obj, sub_obj):
-        return [*self.enter(obj), " no object " + sub_obj]
+        return self.enter(obj) + [" no object " + str(sub_obj)]
 
     def update(self, old, upd, new, obj, sub_obj):
-        return [*self.enter(obj), " object " + sub_obj]
+        return self.enter(obj) + [" object " + str(sub_obj)]
 
 
 
@@ -220,7 +225,7 @@ class Cvt_VRF_RD(DiffConvert_VRF):
     cmd = "rd",
 
     def remove(self, old, vrf):
-        return [*self.enter(vrf), " no rd " + old]
+        return self.enter(vrf) + [" no rd " + old]
 
     def update(self, old, upd, new, vrf):
         l = list(super().enter(vrf))
@@ -234,20 +239,20 @@ class Cvt_VRF_RT(DiffConvert_VRF):
     cmd = "route-target", None, None
 
     def truncate(self, old, rem, new, vrf, dir_, rt):
-        return [*self.enter(vrf), " no route-target %s %s" % (dir_, rt)]
+        return self.enter(vrf) + [" no route-target %s %s" % (dir_, rt)]
 
     def update(self, old, upd, new, vrf, dir_, rt):
-        return [*self.enter(vrf), " route-target %s %s" % (dir_, rt)]
+        return self.enter(vrf) + [" route-target %s %s" % (dir_, rt)]
 
 
 class Cvt_VRF_AF(DiffConvert_VRF):
     cmd = "address-family", None
 
     def remove(self, old, vrf, af):
-        return [*self.enter(vrf), " no address-family " + af]
+        return self.enter(vrf) + [" no address-family " + af]
 
     def add(self, new, vrf, af):
-        return [*self.enter(vrf), " address-family " + af]
+        return self.enter(vrf) + [" address-family " + af]
 
 
 class DiffConvert_VRF_AF(DiffConvert_VRF):
@@ -261,7 +266,7 @@ class Cvt_VRF_AF_RT(DiffConvert_VRF_AF):
     cmd = "route-target", None, None
 
     def truncate(self, old, rem, new, vrf, af, dir_, rt):
-        return [*self.enter(vrf, af), "  no route-target %s %s" % (dir_, rt)]
+        return self.enter(vrf, af) + ["  no route-target %s %s" % (dir_, rt)]
 
     def update(self, old, upd, new, vrf, af, dir_, rt):
-        return [*self.enter(vrf, af), "  route-target %s %s" % (dir_, rt)]
+        return self.enter(vrf, af) + ["  route-target %s %s" % (dir_, rt)]
