@@ -58,6 +58,14 @@ class CiscoIOSDiffConfig(DiffConfig):
             # unconfigured (e.g. HSRP version and high HSRP groups)
             "int-post",
 
+            # for route-map commands we need to delete all removed
+            # entries before we insert any new ones - this is to avoid
+            # clashes of match types, as well as ensure the action for
+            # the entry ('permit' or 'deny') is not reset when removing
+            # a later clauses as these change the entry
+            "rtmap-del",
+            "rtmap-add",
+
             # tracking objects are deleted in the 'None' block,
             # including if they are changing type; the new object is
             # then created, then the sub-configuration (which may need
