@@ -268,6 +268,8 @@ _SERVICE_PORTS = {
     "bootpc": 68,
     "discard": 9,
     "domain": 53,
+    "exec": 512,
+    "finger": 79,
     "ftp": 21,
     "ftp-data": 20,
     "gopher": 70,
@@ -275,10 +277,17 @@ _SERVICE_PORTS = {
     "isakmp": 500,
     "lpd": 515,
     "mail": 25,
+    "netbios-ns": 137,
+    "netbios-ss": 139,
     "non500-isakmp": 4500,
     "ntp": 123,
+    "pop2": 109,
+    "pop3": 110,
     "smtp": 25,
     "snmp": 161,
+    "snmptrap": 162,
+    "sunrpc": 111,
+    "syslog": 514,
     "tftp": 69,
     "www": 80
 }
